////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#ifndef GAMEWIDGET_H
#define GAMEWIDGET_H

#include <qwidget.h>

#include "krepton.h"
#include "map.h"

class QPixmap;

class GameWidget : public QWidget
{
	Q_OBJECT

signals:
	void changedState(bool,bool);
	void changedStats(int,int,int);
	void changedFlags(bool,bool);
	void gameOver();

public:
	GameWidget(QWidget *parent=0, const char *name=0);
	~GameWidget();
	void loadEpisode(const QString& path);
	void loadSprites(const QString& path);
	void loadMaps(const QString& path);
	void startGame(const QString& episode, int level, int points = 0);
	void startGamePassword(const QString& episode, const QString& password);
	void pauseAction();
	void endAction();

	int getPoints() { return (current_map->getPoints()); }

private:
	Map *current_map;

	QPixmap *sprites;
	Map *maps;
	int current_level;
	int num_levels;
	int timerObjects, timerMonsters, timerEggs;
	int timerSecs, timerPlants;
	QString episode_name;
	QPixmap *bgpix;
	QPixmap *pausepix;
	bool in_game,in_pause;
	void endedGame(const QString &how);

public slots:
	void goUp();
        void goDown();
	void goLeft();
	void goRight();

protected:
	void timerEvent(QTimerEvent *e);
	void paintEvent(QPaintEvent *);
	void keyPressEvent(QKeyEvent *e);
};

#endif // !GAMEWIDGET_H
