////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#ifndef GAMEWINDOW_H
#define GAMEWINDOW_H

#include <kmainwindow.h>

#include <qwidget.h>
#include <qptrlist.h>

#include "krepton.h"

class GameWidget;
class KSelectAction;
class KToggleAction;
class KAction;
class QPixmap;
class QLabel;

class GameWindow : public KMainWindow
{
	Q_OBJECT

public:
	GameWindow(QWidget *parent,const char *name);
	void readOptions();
	void saveOptions();
	bool queryClose();

	static bool soundsEnabled() { return (do_sounds); }

private:
	KSelectAction *newGameList;
	KSelectAction *contGameList;
	KSelectAction *loadSpritesList;
	KToggleAction *pauseAction;
	KToggleAction *soundsAction;
	KAction *endGameAction;
	GameWidget *game;
	QPtrList<Episode> episodes;
	Episode *current_episode;
	static bool do_sounds;

	QLabel *keyflag;
	QLabel *crownflag;

	QString prepareGame(int sel,bool spritesonly);

public slots:
	void slotHighScores();
	void slotToggleSounds();

	void updateStats(int diamonds,int secs = -1,int points = -1);
	void updateFlags(bool key,bool crown);
	void updateState(bool ingame,bool inpause);
	void gameOver();

	void slotQuit();
	void slotNewGame();
	void slotContinueGame();
	void slotLoadSprites();
	void slotPauseGame();
	void slotEndGame();
};

#endif // !GAMEWINDOW_H
