////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#ifndef KREPTON_H
#define KREPTON_H

#include <qptrlist.h>

#include <kdebug.h>

class Obj
{
public:	enum Type
	{						// Original Repton objects
		Rock,					// DO NOT CHANGE THE ORDER!
		Diamond,
		Ground1,
		Ground2,
		Time,
		Skull,
		Empty,
		Wall,
		Wall_West,
		Wall_East,
		Wall_North,
		Wall_South,
		Wall_North_West,
		Wall_North_East,
		Wall_South_West,
		Wall_South_East,
		Filled_Wall,
		Filled_Wall_North_West,
		Filled_Wall_North_East,
		Filled_Wall_South_West,
		Filled_Wall_South_East,
		Wall_Mirror,
		Strongbox,
		Cage,
		Egg,
		Key,
		Plant,
		Bomb,
		Transport,
		Crown,
		Repton,
		Blip,
		Blip2,
		Monster,
		Monster2,
		Repton_Look_Left,
		Repton_Look_Right,
		Repton_Go_Right1,
		Repton_Go_Right2,
		Repton_Go_Right3,
		Repton_Go_Right4,
		Repton_Go_Left1,
		Repton_Go_Left2,
		Repton_Go_Left3,
		Repton_Go_Left4,
		Repton_Go_Up1,
		Repton_Go_Up2,
		Broken_Egg,               

		NUM_SPRITES,
							// Non sprites...
		Broken_Egg1,				// Broken egg at stage 1.
		Broken_Egg2,				// Broken egg at stage 2.
		Broken_Egg3,				// Broken egg at stage 3.
		Falling_Egg				// The egg is falling, so will break.
	};
};

typedef Obj::Type SpriteObj;

class Orientation
{
public:	enum Type { North, South, East, West };
};

const int num_sprites = Obj::NUM_SPRITES;
const int sprite_width = 32;
const int sprite_height = 32;

class Sound
{
public:	enum Type
	{
		Cage_Blip,
		Die,
		Broken_Egg,
		Got_Crown,
		Got_Diamond,
		Got_Key,
		Got_Time,
		Kill_Monster,
		Transport
	};
};

struct Episode
{
	QString name;
	QString filename;

	Episode(const QString& xname, const QString& xfilename)
		: name(xname),filename(xfilename) {}
};

extern void loadEpisodeList(QPtrList<Episode>& l);
extern void fatalExit(const QString &);

#endif // !KREPTON_H
