////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#ifndef MAP_H
#define MAP_H

#include <qptrlist.h>

#include "krepton.h"

struct Monster
{
	int xpos, ypos;
	SpriteObj type;
	SpriteObj sprite;
	Orientation::Type orientation;

	Monster(int x, int y, SpriteObj t)
		: xpos(x), ypos(y),
		  type(t), sprite(t),
		  orientation(Orientation::West) {}
};

struct Transporter
{
	int orig_x, orig_y;
	int dest_x, dest_y;

	Transporter(int ox, int oy, int dx, int dy)
		: orig_x(ox), orig_y(oy),
		  dest_x(dx), dest_y(dy) {}
};

class Map
{
public:
	Map();
	~Map();

	int xpos,ypos;					// Repton position
	SpriteObj sprite;
	int num_diamonds;
	int num_secs;
	int num_points;
	bool have_key;
	bool have_crown;

	SpriteObj& ref(int x, int y)
	{
		return (data[y*width + x]);
	}

	SpriteObj xy(int x, int y)
	{
		if (x<0 || y<0 || x>=width || y>=height) return (Obj::Wall);
		return (ref(x,y));
	}

	bool isempty(int x, int y)
	{
		switch (xy(x, y))
		{
case Obj::Empty:
case Obj::Ground1:
case Obj::Ground2:	return (true);

default:		return (false);
		}
	}

	void loadData(const QString& filename);

	void addTransporter(int ox, int oy, int dx, int dy);
	Transporter *findTransporter(int x, int y);
	void addMonster(int x, int y, SpriteObj type);
	void prepareMonsters();
	Monster *findMonster(int x, int y);

	void updateEggs();
	void updateObjects();
	void updateMonsters();
	void updatePlants();
	void goUp() { moveVertical(-1); }
        void goDown() { moveVertical(1); }
	void goLeft() { moveHorizontal(-1); }
	void goRight() { moveHorizontal(1); }
	bool hasDied() { return (how_died!=QString::null); }
	bool hasEndedLevel() { return (status_end_level); }
	QString &howDied() { return (how_died); }

	int getPoints() { return (num_points); }
	void setPoints(int p) { num_points = p; }
	QString &getPassword() { return (password); }
	void startGame();

private:
	bool status_end_level;
	QString how_died;
	QString sounddir;

	int width, height;
	QString password;
	SpriteObj *data;

	QPtrList<Monster> monsters;
	QPtrList<Transporter> transporters;

	void playSound(Sound::Type s);
	bool tryFallDown(int x, int y);
	bool tryFallHorizontal(int x, int y, int xd);
	void tryFallLeftOrRight(int x, int y);
	void tryFall(int x, int y);
	bool blipTryDirection(Monster *m, Orientation::Type dir, int xd, int yd);
	double monsterTryDirection(Monster *m, int xd, int yd);
	void updateBlip(Monster *m);
	void updateMonster(Monster *m);
	bool tryPlant(int x, int y, int dx, int dy);
	bool updatePlant(Monster *m);
	void moveVerticalDirect(int yd);
	void moveHorizontalDirect(int xd);
	void gotKey();
	void gotObject(SpriteObj obj);
	void useTransporter(int x, int y);
	void moveVertical(int yd);
	void moveHorizontalMoveObj(int xd, SpriteObj obj);
	void moveHorizontal(int xd);
	void killMonster(Monster *mp);
	void cageBlip(Monster *m, int x, int y);
	void die(const QString &how);
};

#endif // !MAP_H
