////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#include "config.h"

#include <kapplication.h>
#include <kglobal.h>
#include <kstandarddirs.h>
#include <kmessagebox.h>

#include <qdir.h>
#include <qfile.h>
#include <qtstream.h>
#include <qptrlist.h>
#include <qstringlist.h>

#include <stdlib.h>

#include "krepton.h"

void loadEpisodeList(QPtrList<Episode>& l)
{
	QString path;
	bool loaded = false;

	QStringList dirs = KGlobal::dirs()->findDirs("appdata","episodes");

	for (QStringList::Iterator di = dirs.begin(); di!=dirs.end(); ++di)
	{
		kdDebug(0) << "loadEpisodeList: dir='" << *di << "'" << endl;
		if (*di==QString::null) continue;

		QDir dir(*di);
		if (!dir.exists()) fatalExit(QString("Cannot read episode directory '%1'.\nIs the application properly installed?")
					     .arg(path));
		dir.setFilter(QDir::Dirs);
		dir.setSorting(QDir::Name);

		const QFileInfoList *list = dir.entryInfoList();
		QFileInfoListIterator it(*list);
		QFileInfo *fi;
		while ((fi = it.current()) != 0)
		{
			if (fi->fileName()!="." && fi->fileName()!="..")
			{
				if (!dir.cd(fi->fileName())) fatalExit(QString("Cannot access directory '%1'")
								       .arg(dir.absFilePath(fi->fileName())));

				QString filename = dir.absPath() + "/info";
				QFile f(filename);
				if (!f.open(IO_ReadOnly)) fatalExit(QString("Cannot read information file '%1'")
								    .arg(filename));

				QTextStream t(&f);
				QString name;
				name = t.readLine();
				name = name.stripWhiteSpace();
				f.close();
				dir.cdUp();

				if (name!="blank")	// special for editor only
				{
					Episode *e = new Episode(name, fi->fileName());
					l.append(e);
					loaded = true;
				}
			}
			++it;
		}
	}

	if (!loaded) fatalExit(QString("Cannot find any episodes.\nIs the application properly installed?"));
}

void fatalExit(const QString &s)
{
	KMessageBox::error(NULL,s,"Fatal Error");
	exit(1);
}
