////////////////////////////////////////////////////////////////////////////
//  
//  KRepton - the classic Repton game for KDE
//  
//  Copyright (c) 1998 Sandro Sigala <sandro@sigala.it>
//  Copyright (c) 2003 Jonathan Marten <jjm@keelhaul.demon.co.uk>
//  
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//  
//  It is distributed in the hope that it will be useful, but WITHOUT ANY
//  WARRANTY; without even the implied warranty of MERCHANTABILITY or
//  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
//  for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; see the file COPYING for further details.
//  If not, write to the Free Software Foundation, Inc., 59 Temple Place -
//  Suite 330, Boston, MA 02111-1307, USA.
//
////////////////////////////////////////////////////////////////////////////

#include "config.h"

#include <kglobal.h>
#include <kconfig.h>
#include <klistview.h>

#include <qheader.h>
#include <qlayout.h>

#include "scoredialog.h"


class ScoreListItem : public KListViewItem
{
public:
	ScoreListItem(QListView *parent,QString col1,QString col2,QString col3);
	int compare(QListViewItem *i,int col,bool ascending) const;
};

ScoreListItem::ScoreListItem(QListView *parent,QString col1,QString col2,QString col3)
	: KListViewItem(parent,col1,col2,col3)
{
}

int ScoreListItem::compare(QListViewItem *i,int col,bool ascending) const
{
	if (col!=1) return (key(col,ascending).compare(i->key(col,ascending)));

	int n1 = key(col,ascending).toInt();
	int n2 = i->key(col,ascending).toInt();
	return ((n1==n2) ? 0 : (n1<n2 ? -1 : +1));
}

ScoreDialog::ScoreDialog(QPtrList<Episode>& l,QWidget *parent,const char *name)
        : KDialogBase(parent,name,true,"High Scores",KDialogBase::Close)
{
	KConfig *config = KGlobal::config();
	config->setGroup("High Score");

	QWidget *page = new QWidget(this);
	QVBoxLayout *vl = new QVBoxLayout(page,0,spacingHint());
	setMainWidget(page);

	KListView *list = new KListView(page);
	list->setSelectionMode(QListView::NoSelection);
	list->setItemMargin(4);

	list->addColumn("Episode");
	list->addColumn("Score");
	list->addColumn("Name");

	QString name1,score;
	int h = list->header()->height()+list->itemMargin();
	for (Episode *e = l.first(); e!=0; e = l.next())
	{
		if (e->filename=="---") continue;
		score = config->readEntry(e->filename+"Score","");
		if (score=="0") score = "";
		if (score.isEmpty()) continue;

		name1 = config->readEntry(e->filename+"Name","");
		ScoreListItem *i = new ScoreListItem(list,e->name,score,name1);
		h += i->height();
	}

	list->setFixedSize(list->columnWidth(0)+list->columnWidth(1)+
			   list->columnWidth(2)+(3*2*list->itemMargin()),h);
	vl->addWidget(list);
	vl->addStretch(1);
	adjustSize();
}
